# LOAD LIBRARIES ------------------
library(shiny)
library(shinydashboard)
library(pdftools)
library(readr)
library(dplyr)
library(ggplot2)

#LOAD FUNCTIONS -------------------
source("PdfToText.R")
source("PdfToTableStd.R")
source("PdfToTableCntr.R")
source("PlotFitDiag.R")
source("ExtractRSq.R")
source("PlotStdCurve.R")
source("PlotControls.R")
source("ControlStats.R")

# UI ------------------------------
ui <- dashboardPage(
  dashboardHeader(title = "Dashboard Template"),
  dashboardSidebar(
    fileInput("file", label = h3("File input"))
  ),
  dashboardBody(
    
    h3("Start with Raw PDF"),
    textOutput("text"),
    h3("Std Curve Data"),
    tableOutput("tbl"),
    h3("plot"),
    plotOutput("plot"),
    h3("R^2 is:"),
    textOutput("rsq"),
    h3("Fit Diagnostics"),
    plotOutput("plot2"),
    h3("Assay Control Raw Data"),
    tableOutput("tbl_ac"),
    h3("Assay Control Added to Plot"),
    plotOutput("plot_ac"),
    h3("Relative Error is:"),
    textOutput("rel_er"),
    h3("Relative SD is:"),
    textOutput("rel_sd")
    
  
  )
)

# SERVER -------------------------------------
server <- function(input, output, session) {
  
  output$text <- renderText(PdfToText(
    input$file
  ))
  output$tbl <- renderTable(PdfToTableStd(
    input$file
    ))
  output$plot <- renderPlot(PlotStdCurve(
    PdfToTableStd(input$file)
    ))
  output$plot2 <- renderPlot(PlotFitDiag(
    PdfToTableStd(input$file)
    ))
  output$rsq <- renderText(ExtractRSq(
    PdfToTableStd(input$file)
    ))
  output$tbl_ac <- renderTable(
    PdfToTableCntr(input$file)
    )
  output$plot_ac <- renderPlot(PlotControls(
    PdfToTableStd(input$file),
    PdfToTableCntr(input$file)
  ))
  output$rel_er <- renderText(
    ControlStats(
      PdfToTableCntr(input$file)
    )[[1]]
  )
  output$rel_sd <- renderText(
    ControlStats(
      PdfToTableCntr(input$file)
    )[[2]]
  )
}

shinyApp(ui, server)